@@ -7,14 +7,14 @@ make.geosse.t <- function(tree, states, functions, sampling.f=NULL,
   cache <- make.cache.geosse.t(tree, states,  functions, sampling.f,
                                strict, truncate, spline.data)
 
-  all.branches <- make.all.branches.t.dtlik(cache, control,
+  all_branches <- make.all_branches.t.dtlik(cache, control,
                                             initial.conditions.geosse)
 
    rootfunc <- make.rootfunc.t(cache, rootfunc.geosse)
 
   ll <- function(pars, condition.surv=TRUE, root=ROOT.OBS,
                  root.p=NULL, intermediates=FALSE) {
-    ans <- all.branches(pars, intermediates)
+    ans <- all_branches(pars, intermediates)
     rootfunc(ans, pars, condition.surv, root, root.p, intermediates)
   }
   class(ll) <- c("geosse.t", "geosse", "dtlik", "function")
